Skip to contents

plotPaintedWhales plots the phylogeny from Steeman et al (2011), coloring the Dolphins (Delphinidae), porpoises (Phocoenidae), the Mysticetes, the baleen whales (Balaenopteridae), and the Beaked whales (Ziphiidae).

Usage

plotPaintedWhales(
  show.legend = TRUE,
  direction = "rightwards",
  knitr = FALSE,
  ...
)

Arguments

show.legend

Logical indicating if clade legend should be shown.

direction

Phylogeny plotting direction. Should be set to "rightwards"

knitr

Logical indicating if plot is intended to show up in RMarkdown files made by the Knitr R package. (the default) or "leftwards".

...

other arguments to be passed to phytools::plotSimmap

Value

The whale phylogeny, with branch lengths being colored by a major whale taxonomic group.

References

Steeman, M. E., Hebsgaard, M. B., Fordyce, R. E., Ho, S. Y., Rabosky, D. L., Nielsen, R., ... & Willerslev, E. (2009). Radiation of extant cetaceans driven by restructuring of the oceans. Systematic biology, 58(6), 573-585.

Author

Matheus Januario, Jennifer Auler

Examples

plotPaintedWhales(knitr = TRUE)
#> no colors provided. using the following legend:
#>                    1        Baleen whales        Beaked whales 
#>              "black"            "#DF536B"            "#61D04F" 
#> Belugas and narwhals             Dolphins     Other mysticetes 
#>            "#2297E6"            "#28E2E5"            "#CD0BBC" 
#>            Porpoises 
#>            "#F5C710"